//
//  NFCReadViewController.m
//  AsReader 6Combo
//
//  Created by mac on 2019/2/13.
//

#import "NFCReadViewController.h"
#import "ModelSettings.h"
#import "GlobalDefine.h"
#import "Utils.h"
#import "ComboDevices.h"

@interface NFCReadViewController ()<RcpNFCDelegate>
@property (nonatomic,retain) ModelSettings *m_Model;
@property (nonatomic,retain) ComboNFCApi *device;
@end

@implementation NFCReadViewController

- (void)viewDidLoad {
    [super viewDidLoad];
    self.device  = [ComboNFCApi sharedInstance];
    self.device.delegateNFC = self;
    self.readButton.layer.masksToBounds = YES;
    self.readButton.layer.cornerRadius = 5;
    self.readTextView.layer.masksToBounds = YES;
    self.readTextView.layer.cornerRadius = 5;
    self.readTextView.layer.borderColor = [[UIColor lightGrayColor] CGColor];
    self.readTextView.layer.borderWidth = 0.5;
    self.m_Model          = [ModelSettings sharedInstance];
    NSDictionary    *dic  = [self.m_Model.m_arReadTagData objectAtIndex:self.m_Model.m_nSelectTagNum];
    NSString *strData    = [dic objectForKey:df_CELL_TAG_INFO];
    [self setTextBlockAttributed:[NSString stringWithFormat:@"UID : %@",strData]];
}



#pragma mark - Action
- (IBAction)readAction:(id)sender {
    [self.view endEditing:YES];
    if (![Utils checkNumberTextLength:self.blockIndexTextField.text maxNumber:255 minNumber:0]) {
        [self setTextBlockAttributed:@"The value of the block index is in the range 0-255. Please enter a valid value"];
        return;
    } else if (![Utils checkNumberTextLength:self.blockCountTextField.text maxNumber:255 minNumber:0]) {
        [self setTextBlockAttributed:@"The value of the block count is in the range 0-255. Please enter a valid value"];
        return;
    } else {
        [self.device readMultiBlockWithBlockIndex:[self.blockIndexTextField.text intValue] count:[self.blockCountTextField.text intValue]];
    }
}

- (void)touchesBegan:(NSSet<UITouch *> *)touches withEvent:(UIEvent *)event{
    [self.view endEditing:YES];
}

#pragma mark NFC Recieve
- (void)nfcDataReceived:(NSData *)data{
    NSLog(@"nfcDataReceived APP: %@",data);
}

- (void)nfcReadMultiBlockReceived:(NSArray *)dataArray statusCode:(ComboStatusCode)statusCode{
    if (statusCode == Combo_STS_OK) {
        NSInteger blockIndex = [self.blockIndexTextField.text integerValue];
        NSMutableString *allBlockString = [[NSMutableString alloc] init];
        for (int i = 0; i < dataArray.count; i++){
            NSString * blockString = [NSString stringWithFormat:@"Block %ld:\n%@\n", (long)blockIndex, [dataArray objectAtIndex:i]];
            [allBlockString appendString:blockString];
            blockIndex ++;
        }
        [self setTextBlockAttributed:allBlockString];
        [Utils showAlert:@"Read Success" message:@"" view:self];
    } else {
        [Utils showAlert:@"Read Failed" message:[NSString stringWithFormat:@"StatusCode：0x%02lx", (unsigned long)statusCode] view:self];
    }
}

#pragma mark private
- (void)setTextBlockAttributed:(NSString *)text{
    NSMutableAttributedString *string = [[NSMutableAttributedString alloc]initWithString:text];
    [string addAttribute:NSFontAttributeName value:[UIFont systemFontOfSize:20] range:NSMakeRange(0, text.length)];
    NSArray * array = [text componentsSeparatedByString:@"\n"];
    for (NSString * str in array) {
        if ([str hasPrefix:@"Block"]) {
            [string addAttribute:NSForegroundColorAttributeName value:[UIColor blueColor] range:[text rangeOfString:str]];
        }else{
            [string addAttribute:NSForegroundColorAttributeName value:[UIColor blackColor] range:[text rangeOfString:str]];
        }
    }
    [self.readTextView setAttributedText:string];
}



- (void)didReceiveMemoryWarning {
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

/*
#pragma mark - Navigation

// In a storyboard-based application, you will often want to do a little preparation before navigation
- (void)prepareForSegue:(UIStoryboardSegue *)segue sender:(id)sender {
    // Get the new view controller using [segue destinationViewController].
    // Pass the selected object to the new view controller.
}
*/

@end
