//
//  NFCWriteViewController.m
//  AsReader 6Combo
//
//  Created by mac on 2019/2/13.
//

#import "NFCWriteViewController.h"
#import "ModelSettings.h"
#import "GlobalDefine.h"
#import "Utils.h"
#import "ComboDevices.h"

typedef NS_ENUM (NSUInteger, NFCWriteOptions) {
    NFCWriteSingleBlock = 0,
    NFCWriteBytes,
};

@interface NFCWriteViewController ()<RcpNFCDelegate, UITextFieldDelegate>
@property (nonatomic,retain) ModelSettings *m_Model;
@property (nonatomic,retain) ComboNFCApi *device;
@end

@implementation NFCWriteViewController{
    NFCWriteOptions nfcWriteOptions;
}

- (void)viewDidLoad {
    [super viewDidLoad];
    self.device  = [ComboNFCApi sharedInstance];
    self.device.delegateNFC = self;
    self.writeButton.layer.masksToBounds = YES;
    self.writeButton.layer.cornerRadius = 5;
    self.m_Model          = [ModelSettings sharedInstance];
    NSDictionary    *dic  = [self.m_Model.m_arReadTagData objectAtIndex:self.m_Model.m_nSelectTagNum];
    NSString *UIDString = [dic objectForKey:df_CELL_TAG_INFO];
    NSMutableString *string = [[NSMutableString alloc] init];
    for (int i = 1 ; i < 9; i++) {
        [string appendString: [UIDString substringWithRange:NSMakeRange(UIDString.length - i*2 , 2)]];
    }
    NSLog(@"%@ %@",string,UIDString);
    self.uidTextField.text = [string uppercaseString];
    nfcWriteOptions = NFCWriteSingleBlock;
    self.segmentControl.selectedSegmentIndex = nfcWriteOptions;
    [self nfcWriteParamsExplain:nfcWriteOptions];
}

#pragma mark UITextFieldDelegate
- (BOOL)textField:(UITextField *)textField shouldChangeCharactersInRange:(NSRange)range replacementString:(NSString *)string{
    if ([Utils isCorrectWriteData:[textField.text stringByAppendingString:string]]) {
        return YES;
    } else {
        return NO;
    }
}

#pragma mark Action
- (void)touchesBegan:(NSSet<UITouch *> *)touches withEvent:(UIEvent *)event{
    [self.view endEditing:YES];
}

- (IBAction)onClickWriteButton:(id)sender {
    [self.view endEditing:YES];
    if (![Utils checkNumberTextLength:self.blockIndexTextField.text maxNumber:255 minNumber:0]) {
        [Utils showAlert:@"" message:@"The value of the block index is in the range 0-255. Please enter a valid value" view:self];
        return;
    } else {
        if (nfcWriteOptions == NFCWriteSingleBlock) {
            [self.device writeSingleBlockWithBlockIndex:[self.blockIndexTextField.text intValue] writeData:[Utils convertHexStrToData:self.writeDataTextFiled.text] uid:[Utils convertHexStrToData:self.uidTextField.text]];
        } else {
            [self.device writeBytesWithBlockIndex:[self.blockIndexTextField.text intValue] writeData:[Utils convertHexStrToData:self.writeDataTextFiled.text] uid:[Utils convertHexStrToData:self.uidTextField.text]];
        }
    }
}

- (IBAction)onClickSegment:(UISegmentedControl *)sender {
    nfcWriteOptions = self.segmentControl.selectedSegmentIndex;
    [self nfcWriteParamsExplain:nfcWriteOptions];
}

#pragma mark NFC Recieve
- (void)nfcDataReceived:(NSData *)data{
    NSLog(@"nfcDataReceived APP: %@",data);
}

- (void)nfcWriteSingleBlockStatusCode:(ComboStatusCode)statusCode{
    [self checkStatusCode:statusCode];
}

- (void)nfcWriteBytesStatusCode:(ComboStatusCode)statusCode{
    [self checkStatusCode:statusCode];
}

- (void)checkStatusCode:(ComboStatusCode)statusCode{
    if (statusCode == Combo_STS_OK) {
        [Utils showAlert:@"Write Success" message:@"" view:self];
    } else {
        [Utils showAlert:@"Write Failed" message:[NSString stringWithFormat:@"StatusCode：0x%02lx", (unsigned long)statusCode] view:self];
    }
}

#pragma mark private
- (void)nfcWriteParamsExplain:(NFCWriteOptions)explanin{
    if (explanin == NFCWriteSingleBlock) {
        self.explainTextView.text = @"指定された UID を持つ IC タグのメモリ上の指定したブロックへデータを書き込む。";
    } else {
        self.explainTextView.text = @"指定された UID を持つ指定ブロックから指定バイト数のデータを書き込む ※ タグへのデータの書き込みはブロック単位に行われます。 書き込むデータ長(データのバイト数)がブロックサイズに満たない場合、書き込まれる最終 ブロックのデータは、最後に「0x00」が付加され書き込まれます。";
    }
}

- (void)didReceiveMemoryWarning {
    [super didReceiveMemoryWarning];
}

@end
