//  RFIDFuntionsList.m
//  Created by Robin on 2016. 5. 16..

#import "RFIDFuntionsList.h"
#import "ModelSettings.h"
#import "GlobalDefine.h"
#import "Indicator.h"
#import "imageAlert.h"

/*SDK header files*/
#import "ComboDevices.h"

@interface RFIDFuntionsList()
{
}
@property(nonatomic, retain)  ModelSettings *m_Model;
@property(nonatomic, retain)  ComboRFIDApi       *m_RFIDDevice;
@property(nonatomic, retain)  CommonDevice  *m_CommonDevice;

@property (weak, nonatomic) IBOutlet UILabel *olPowerLever;
@property (weak, nonatomic) IBOutlet UILabel *olStopCondition;
@property (weak, nonatomic) IBOutlet UILabel *olOnOffTime;
@property (weak, nonatomic) IBOutlet UILabel *olRFChannel;
@property (weak, nonatomic) IBOutlet UILabel *olEncording;
@property (weak, nonatomic) IBOutlet UILabel   *olThresholdValue;
@property (weak, nonatomic) IBOutlet UISwitch *btnPAGainMode;

@property (weak, nonatomic) IBOutlet UISwitch           *olSwitchRSSIOn;
@property (weak, nonatomic) IBOutlet UISwitch           *olHopping;
@property (weak, nonatomic) IBOutlet UILabel *olAntiCollisionMode;
@property(nonatomic,retain)   UIAlertView   *alert;

- (IBAction)actionRSSISwitch:(UISwitch *)sender;
- (IBAction)btnSaveRegistry:(id)sender;
- (IBAction)btnPAGainMode:(id)sender;
@end


@implementation RFIDFuntionsList

-(void)viewDidLoad
{
    [super viewDidLoad];
    self.alert = [[UIAlertView alloc]initWithTitle:nil message:@"" delegate:nil cancelButtonTitle:nil otherButtonTitles:@"OK", nil];
}


-(void)viewWillAppear:(BOOL)animated
{
    [super viewWillAppear:YES];
    self.m_Model             = [ModelSettings sharedInstance];
    self.m_RFIDDevice        = [ComboRFIDApi sharedInstance];
    self.m_CommonDevice      = [CommonDevice sharedInstance];
    
    self.m_CommonDevice.delegateCommon = self;
    self.m_RFIDDevice.delegateRFID =self;
    
    int nEncording = (int)[[NSUserDefaults standardUserDefaults]integerForKey:@"RFIDEncoding"];
    
    switch (nEncording)
    {
        case df_ENCODINGTYPE_HEX:
            self.olEncording.text       = @"HEX";
            break;
        case df_ENCODINGTYPE_ASCII:
            self.olEncording.text       = @"ASCII";
            break;
        case df_ENCODINGTYPE_EAN13:
            self.olEncording.text       = @"EAN13";
            break;
        case df_ENCODINGTYPE_SGTIN96:
            self.olEncording.text       = @"SGTIN96";
            break;
        default:
            self.olEncording.text       = @"Unknow";
            break;
    }
    
    self.olPowerLever.text              = @"---";
    self.olStopCondition.text           = @"---";
    self.olOnOffTime.text               = @"---";
    self.olRFChannel.text               = @"---";
    self.m_CommonDevice.delegateRFID   = self;
    
    
    BOOL isRSSIOn =[[NSUserDefaults standardUserDefaults] boolForKey:@"RSSIOn"];
    
    [self.olSwitchRSSIOn setOn:isRSSIOn];
    
    
    int nTagCount =(int)[[NSUserDefaults standardUserDefaults] integerForKey:@"RFIDScanTagCount"];
    int nScanTime =(int)[[NSUserDefaults standardUserDefaults] integerForKey:@"RFIDScanTagTime"];
    int nCycle    =(int)[[NSUserDefaults standardUserDefaults] integerForKey:@"RFIDScanTagInventory"];
    
    
    dispatch_async(dispatch_get_main_queue(),^{
        self.olStopCondition.text  =  [NSString stringWithFormat:@"%d/%d/%d",
                                       nTagCount,
                                       nScanTime,
                                       nCycle];}
                   );
    
    //Power
    [self performSelector:@selector(onTickRFIDPowerFuntion)     withObject:nil afterDelay:.2f];
    
    //Stop
    [self performSelector:@selector(onTickStopConditionFuntion) withObject:nil afterDelay:.4f];
    
    //OnOffTime
    [self performSelector:@selector(onTickOnOffTimeFuntion)     withObject:nil afterDelay:.6f];
    
    //Channel
    [self performSelector:@selector(onTickOnChannelFuntion)     withObject:nil afterDelay:.8f];
    
    //AntiCollison
    [self performSelector:@selector(onTickAnticollisionFuntion)     withObject:nil afterDelay:1.0f];
    
    /* Request PA GAIN MODE & RSSI ThresHold for RED4S */
    CommonReaderInfo  *info = [CommonReaderInfo sharedInstance];
  

    float hwVer = [info.strhardware floatValue];

    /* HW Version 1.X.X  RED 4    2.X.X = RED4S */
    if(hwVer >= 2.0)
    {
        // RSSI Threshold
        [self performSelector:@selector(onTickThresholdFuntion)   withObject:nil afterDelay:1.4f];
    }else{
        [self.view setUserInteractionEnabled:YES];
    }
}

- (void)rssiThresholdReceived:(uint16_t)threshold
{
    [_olThresholdValue setText:[NSString stringWithFormat:@"%d",threshold]];
}

- (void) onTickThresholdFuntion
{
    [self.m_RFIDDevice getRSSIThreshold];
}

- (void) onTickAnticollisionFuntion
{
    [self.m_RFIDDevice getAnticollision];
}

- (void) onTickStopConditionFuntion
{
    [self.m_RFIDDevice getStopCondition];
}

- (void) onTickRFIDPowerFuntion
{
    [self.m_RFIDDevice getOutputPowerLevel];
}

- (void) onTickOnOffTimeFuntion
{
    [self.m_RFIDDevice getRFIDOnOffTime];
    
}

- (void) onTickOnChannelFuntion
{
    [self.m_RFIDDevice getChannel];
}

- (IBAction)btnSaveRegistry:(id)sender
{
    
    //Sotre data into Registry
    [self.m_RFIDDevice updateRegistry];
}

- (void)updatedRegistry:(uint8_t)status
{
    
    NSString *strResult = @"";
    
    //Sucess
    if(status == 0x00)
    {
        strResult = @"Successfully Stored Data into Registry. Please Reset Hardware.";
    }
    else
    {
        strResult = @"Fail Store into Registry";
    }
    
    UIAlertView *alert = [[UIAlertView alloc] initWithTitle:@"Update Registry Result"
                                                    message:strResult
                                                   delegate:nil
                                          cancelButtonTitle:@"OK"
                                          otherButtonTitles:nil];
    
    dispatch_async(dispatch_get_main_queue(),
                   ^{
                       [alert show];
                   });
    
}




- (IBAction)actionRSSISwitch:(UISwitch *)sender
{
    UISwitch *sw = (UISwitch*)sender;
    
    [[NSUserDefaults standardUserDefaults] setBool:sw.isOn forKey:@"RSSIOn"];
    [[NSUserDefaults standardUserDefaults] synchronize];
    
    
}




#pragma mark - CommonDelegate
//Reader (RFID Module Info)

/***********************************************************************/
#pragma mark ON OFF Time
/***********************************************************************/

/*RFID ON/OFF Time Received*/
- (void)rfidOnOffTimeReceived:(NSData*)data
{
    CommonReaderInfo *info = [CommonReaderInfo sharedInstance];
    NSLog(@"[ONOFF] ON Time %d",info.nRFIDonTime);
    NSLog(@"[ONOFF] OFF Time %d",info.nRFIDoffTime);
    NSLog(@"[ONOFF] nCst %d",info.nCst);
    NSLog(@"[ONOFF] nRfl %d",info.nRfl);
    NSLog(@"[ONOFF] nLbt %d",info.nLbt);
    NSLog(@"[ONOFF] nCw %d",info.nCw);
    NSLog(@"[ONOFF] PH %d",info.nFh);
    
    dispatch_async(dispatch_get_main_queue(),
                   ^{
                       self.olOnOffTime.text     =  [NSString stringWithFormat:@"%d/%d",info.nRFIDonTime,info.nRFIDoffTime];
                   });
    
    
    
}



/***********************************************************************/
#pragma mark Channel
/***********************************************************************/

#pragma mark - RFID Delegate
- (void)channelReceived:(uint8_t)channel channelOffset:(uint8_t)channelOffset
{
    dispatch_async(dispatch_get_main_queue(),
                   ^{
                       CommonReaderInfo *info = [CommonReaderInfo sharedInstance];
                       self.m_Model.m_RFIDDeviceInfo.m_nRFID_RF_CHANNEL = info.nRFIDchannel;
                       [self.olRFChannel setText:[NSString stringWithFormat:@"%d",info.nRFIDchannel]];
                   });
}


/***********************************************************************/
#pragma mark TX Power
/***********************************************************************/


- (void)txPowerLevelReceived:(NSData*)power
{
    CommonReaderInfo *info = [CommonReaderInfo sharedInstance];
    dispatch_async(dispatch_get_main_queue(),
                   ^{
                       self.olPowerLever.text     = [NSString stringWithFormat:@"%02.1f", info.fRFIDpower/10.0];}
                   );
    
}




/***********************************************************************/
#pragma mark AntiCollisionMode
/***********************************************************************/
- (void)anticolParamReceived:(uint8_t)mode Counter:(uint8_t)counter
{
    ModelSettings *model = [ModelSettings sharedInstance];
    model.m_RFIDDeviceInfo.m_nAntiMode   = mode;
    dispatch_async(dispatch_get_main_queue(),
                   ^{
                       self.olAntiCollisionMode.text = [NSString stringWithFormat:@"Mode :%d", model.m_RFIDDeviceInfo.m_nAntiMode];
                   });
    
}

- (void)didSetAntiCol:(uint8_t)status
{
    switch (status) {
        case 0x00:
        {
            dispatch_async(dispatch_get_main_queue(), ^{
                
                UIAlertView *alert = [[UIAlertView alloc] initWithTitle:nil message:@"Anti-Collision Updated." delegate:nil cancelButtonTitle:nil otherButtonTitles:@"OK", nil];
                [alert show];
            });
        }
            break;
        default:
            break;
    }
}

//-(void) showAlert:(NSString*)strMsg
//{
//    dispatch_async(dispatch_get_main_queue(),
//                   ^{
//                       [self.alert setMessage:strMsg];
//                       [self.alert show];
//                   });
//}
//
//- (void)ackReceived:(uint8_t)commandCode
//{
//    if(commandCode == 0x00)
//    {
//        [self showAlert:@"Success"];
//    }
//    else{
//        [self showAlert:@"FAIL"];
//    }
//}

@end
