//  SettingPopController.m

#import "SettingsPopController.h"
#import "ModelSettings.h"
#import "Utils.h"
/*SDK header files*/
#import "ComboDevices.h"

@interface SettingsPopController ()
{
    BOOL mIsBeep;
    BOOL mIsVib;
    BOOL mIsLed;
    BOOL mIsIllu;
}
- (IBAction)eBeepChanged:(id)sender;
- (IBAction)eVibrationChanged:(id)sender;
- (IBAction)eLEDChanged:(id)sender;
- (IBAction)eIlluminationChanged:(id)sender;
- (IBAction)eAutoPower:(id)sender;
- (IBAction)eTriggerDefault:(id)sender;
- (IBAction)eFactoryReset:(id)sender;
- (IBAction)ePowerOnBeep:(id)sender;
- (IBAction)eSymbologyPrefix:(id)sender;
- (IBAction)eChargingControl:(id)sender;
- (IBAction)eChangeUserCommand:(id)sender;
- (IBAction)eSetUserCommand:(id)sender;
- (IBAction)onClickDisplyDisconnectedTimeButton:(id)sender;

@property(nonatomic,retain) CommonDevice  *m_Commdevice;
@property(nonatomic,retain) ModelSettings *m_Model;
@property (weak, nonatomic) IBOutlet UISwitch *olBeep;
@property (weak, nonatomic) IBOutlet UISwitch *olIllumination;
@property (weak, nonatomic) IBOutlet UISwitch *olVibration;
@property (weak, nonatomic) IBOutlet UISwitch *olLED;
@property (weak, nonatomic) IBOutlet UISwitch *olAutoPower;
@property (weak, nonatomic) IBOutlet UISwitch *olDefaultTriggerOn;
@property (weak, nonatomic) IBOutlet UISwitch *olPowerOnBeep;
@property (weak, nonatomic) IBOutlet UISwitch *olSymbologyPrefix;
@property (weak, nonatomic) IBOutlet UISwitch *olChargingControl;
@property (weak, nonatomic) IBOutlet UITextField *olUserCommand;
@property (strong, nonatomic) IBOutlet UITextField *displayDisconnectedTime;


@property (nonatomic,retain) UIAlertView*  mAlert;
//@property (weak, nonatomic) IBOutlet UILabel *olLabeFactoryStatus;

/*20190909*/
@property  (weak,nonatomic) IBOutlet UITableViewCell *olCellFactory;
@property  (weak,nonatomic) IBOutlet UITableViewCell *olCellChargingControl;
@property  (weak,nonatomic) IBOutlet UITableViewCell *olCellDefaultTrigger;
@property  (weak,nonatomic) IBOutlet UITableViewCell *olCellSymbologyPrefix;
@property  (weak,nonatomic) IBOutlet UITableViewCell *olCellBarcodeUserCommand;

@end

@implementation SettingsPopController


- (IBAction)eChargingControl:(id)sender
{
    UISwitch *sw = (UISwitch*)sender;
    
    [self.m_Commdevice setChargingControl:sw.isOn];
    [self saveSettingVal];
}

- (IBAction)eFactoryReset:(id)sender
{
    [self showAlert:@"Completed Factory Reset"];
    ComboBarcodeApi *barcode = [ComboBarcodeApi sharedInstance];
    [barcode setFactoryReset];
    
}

- (id)initWithStyle:(UITableViewStyle)style
{
    self = [super initWithStyle:style];
    if (self)
    {
        // Custom initialization
    }
    return self;
}

- (void)viewDidLoad
{
    [super viewDidLoad];
    [self showHideCell];
    self.m_Commdevice = [CommonDevice sharedInstance];
    self.m_Model      = [ModelSettings sharedInstance];
    self.m_Commdevice.delegateCommon  = self;
    self.mAlert = [[UIAlertView alloc]initWithTitle:nil message:@"" delegate:nil cancelButtonTitle:nil otherButtonTitles:@"OK", nil];
    
    self.olUserCommand.delegate = self;
    
    BOOL isAutoPower  = [[NSUserDefaults standardUserDefaults] boolForKey:@"AutoPowerOn"];
    BOOL isDefaultTriggerOn  = [[NSUserDefaults standardUserDefaults] boolForKey:@"DefaultTriggerOn"];
    BOOL isBeepOn  =[[NSUserDefaults standardUserDefaults] boolForKey:@"beep"];
    BOOL isVirbOn  =[[NSUserDefaults standardUserDefaults] boolForKey:@"vibration"];
    BOOL isLedOn   =[[NSUserDefaults standardUserDefaults] boolForKey:@"led"];
    BOOL isIllumOn =[[NSUserDefaults standardUserDefaults] boolForKey:@"illumination"];
    BOOL isPowerOnBeep =[[NSUserDefaults standardUserDefaults] boolForKey:@"powerOnBeep"];
    BOOL isSymbologyPrefix =[[NSUserDefaults standardUserDefaults] boolForKey:@"SymbologyPrefix"];
    NSString * displayDisconnectedTime =  [[NSUserDefaults standardUserDefaults] valueForKey:@"DisplayDisconnectedTime"]?:@"0";
    [_displayDisconnectedTime setText:displayDisconnectedTime];
    [self.olSymbologyPrefix    setOn:isSymbologyPrefix];
    
    [self.olPowerOnBeep     setOn:isPowerOnBeep];
    [self.olBeep            setOn:isBeepOn];
    [self.olVibration       setOn:isVirbOn];
    [self.olLED             setOn:isLedOn];
    [self.olIllumination    setOn:isIllumOn];
    
    [self.olDefaultTriggerOn setOn:isDefaultTriggerOn];
    [self.olAutoPower        setOn:isAutoPower];
}

-(void)getDeviceInfo
{
    //Common
    [self.m_Commdevice getReaderInfo:00];
}

-(void)viewWillAppear:(BOOL)animated
{
    [super viewWillAppear:YES];
}

-(void)viewDidDisappear:(BOOL)animated
{
    [super viewDidDisappear:YES];
    [[NSNotificationCenter defaultCenter] removeObserver:self];
}

-(void)saveSettingVal
{
    [self.m_Commdevice setBeep:self.olBeep.isOn setVibration:self.olVibration.isOn setIllumination:self.olIllumination.isOn setLED:self.olLED.isOn];
    [[NSUserDefaults standardUserDefaults] setBool:self.olBeep.isOn forKey:@"beep"];
    [[NSUserDefaults standardUserDefaults] setBool:self.olIllumination.isOn forKey:@"illumination"];
    [[NSUserDefaults standardUserDefaults] setBool:self.olVibration.isOn forKey:@"vibration"];
    [[NSUserDefaults standardUserDefaults] setBool:self.olLED.isOn forKey:@"led"];
    [[NSUserDefaults standardUserDefaults] setBool:self.olPowerOnBeep.isOn forKey:@"powerOnBeep"];
    
    
    [[NSUserDefaults standardUserDefaults] setBool:self.olSymbologyPrefix.isOn forKey:@"SymbologyPrefix"];
    [[NSUserDefaults standardUserDefaults] synchronize];
}

- (BOOL)textFieldShouldReturn:(UITextField *)textField{
    [textField resignFirstResponder];
    return YES;
}

-(void) showAlert:(NSString*)strMsg
{
    if(self.mAlert == nil)
        self.mAlert = [[UIAlertView alloc]initWithTitle:nil message:@"" delegate:nil cancelButtonTitle:nil otherButtonTitles:@"OK", nil];
    
    [self.mAlert setMessage:strMsg];
    [self.mAlert show];
}


- (void)resFactoryRset:(uint8_t)status
{
    
    dispatch_async(dispatch_get_main_queue(),
                   ^{
                       
                       switch (status)
                       {
                           case 0x00:
                           {
                               NSString *strMsg =@"Res : Doing Reset .... ";
                               [self showAlert:strMsg];
                               
                           }
                               break;
                               
                           case 0xFF:
                           {
                               NSString *strMsg =@"Completed Factory Reset for Barcode";
                               [self showAlert:strMsg];
                           }
                               break;
                               
                           default:
                               break;
                       }
                       
                   });
    
    
}


- (IBAction)eSymbologyPrefix:(id)sender;
{
    [[NSUserDefaults standardUserDefaults] setBool:self.olSymbologyPrefix.isOn forKey:@"SymbologyPrefix"];
    [[NSUserDefaults standardUserDefaults] synchronize];
    
    ComboBarcodeApi *bar = [ComboBarcodeApi sharedInstance];
    
    if([self.olSymbologyPrefix isOn])
        [bar setSymbologyPrefix];
    else
        [bar setDisableSymbologyPrefix];
    
    
}

//Power On Beep
- (IBAction)ePowerOnBeep:(id)sender
{
    [self saveSettingVal];
    
    ComboBarcodeApi *bar = [ComboBarcodeApi sharedInstance];
    
    if([self.olPowerOnBeep isOn])
        [bar setBarcodeEngineUserCommand:@"BEPPWR1."];
    else
        [bar setBarcodeEngineUserCommand:@"BEPPWR0."];
    
}



//Beep
- (IBAction)eBeepChanged:(id)sender
{
    [self saveSettingVal];
}


//Illumination
- (IBAction)eIlluminationChanged:(id)sender
{
    [self saveSettingVal];
}

//Vibration
- (IBAction)eVibrationChanged:(id)sender
{
    [self saveSettingVal];
}


//LED
- (IBAction)eLEDChanged:(id)sender
{
    [self saveSettingVal];
}


//Auto Power On /OFF
- (IBAction)eAutoPower:(id)sender
{
    UISwitch *sw = (UISwitch*)sender;
    [[NSUserDefaults standardUserDefaults] setBool:[sw isOn] forKey:@"AutoPowerOn"];
    
}


//Trigger
- (IBAction)eTriggerDefault:(id)sender
{
    UISwitch *sw = (UISwitch*)sender;
    [CommonDevice setTriggerModeDefault: [sw isOn]];
    
    [[NSUserDefaults standardUserDefaults] setBool:[sw isOn] forKey:@"DefaultTriggerOn"];
    [[NSUserDefaults standardUserDefaults] synchronize];
}

- (IBAction)eChangeUserCommand:(id)sender {
    UISegmentedControl *seg = (UISegmentedControl*)sender;
    // Manual Mode
    if(seg.selectedSegmentIndex == 0)
        _olUserCommand.text = @"PAPHHF.";
    
    //Presentation Mode
    if(seg.selectedSegmentIndex == 1)
        _olUserCommand.text = @"TRGMOD3.";
}

- (IBAction)eSetUserCommand:(id)sender{
    ComboBarcodeApi *barcode = [ComboBarcodeApi sharedInstance];
    NSString *strCmd =_olUserCommand.text;
    
    if(strCmd.length<1)
    {
        [Utils showAlert:@"Error" message:@"Please check User command" view:self];
        return;
    }
    
    [barcode setBarcodeEngineUserCommand:strCmd];
}

- (IBAction)onClickDisplyDisconnectedTimeButton:(id)sender {
    if (_displayDisconnectedTime.text.length == 0) {
        _displayDisconnectedTime.text = @"0";
    }
    if (_displayDisconnectedTime.text.intValue <= 8
        && _displayDisconnectedTime.text.intValue >= 0) {
        [_displayDisconnectedTime resignFirstResponder];
        [[CommonDevice sharedInstance] setDelayDisconnectOnBackground:_displayDisconnectedTime.text.intValue];
        [[NSUserDefaults standardUserDefaults] setValue:_displayDisconnectedTime.text forKey:@"DisplayDisconnectedTime"];
    }
}

-(void)ackUserCommandReceived:(NSData *)rawData
{
    NSString *ackCommand = [[NSString alloc]
                            initWithData:rawData
                            encoding:NSASCIIStringEncoding];
    
    
    [Utils showAlert:@"Ack from Barcode engine" message:ackCommand view:self];
}
- (BOOL)textField:(UITextField *)textField shouldChangeCharactersInRange:(NSRange)range replacementString:(NSString *)string{
    if ([textField isEqual:_displayDisconnectedTime]) {
        if ([string isEqualToString:@""]) {
            return YES;
        }
        if (textField.text.length >= 1 ) {
            return NO;
        }else{
            if ([string intValue] > 8) {
                textField.text = @"0";
                return NO;
            }
            return YES;
        }
    }else{
        return YES;
    }
}


-(void)showHideCell{
    CommonReaderInfo *info = [CommonReaderInfo sharedInstance];
    NSString *strModel = info.strmodelNumber;
    
    //Charging control : 010,020,022,03XD
    if(!([strModel isEqualToString:@"ASR-010D"]
         ||[strModel isEqualToString:@"ASR-020D"]
         ||[strModel isEqualToString:@"ASR-022D"]
         ||[strModel isEqualToString:@"ASR-030D"]
         ||[strModel isEqualToString:@"ASR-031D"]
         ||[strModel isEqualToString:@"ASR-0230DV2"]))
    {
        NSLog(@"ChargingControl");
        _olCellChargingControl.hidden = YES;
    }
    
    //Default Trigger control : 023X,0240,03XD,022D
    if(!([strModel isEqualToString:@"ASR-0230D"]
         ||[strModel isEqualToString:@"ASR-0231D"]
         ||[strModel isEqualToString:@"ASR-0240D"]
         ||[strModel isEqualToString:@"ASR-022D"]
         ||[strModel isEqualToString:@"ASR-030D"]
         ||[strModel isEqualToString:@"ASR-031D"]
         ||[strModel isEqualToString:@"ASR-0230DV2"]))
    {
        NSLog(@"DefaultTrigger");
        _olCellDefaultTrigger.hidden = YES;
    }
    
    
    //Symbology Prefix
    //Factory Reset
    //User Command
    //ASR-020XD , 0240D, 022D
    if(!([strModel isEqualToString:@"ASR-0230D"]
         ||[strModel isEqualToString:@"ASR-0231D"]
         ||[strModel isEqualToString:@"ASR-0240D"]
         ||[strModel isEqualToString:@"ASR-022D"]
         ||[strModel isEqualToString:@"ASR-0230DV2"]))
    {
        _olCellSymbologyPrefix.hidden = YES;
        _olCellFactory.hidden = YES;
        _olCellBarcodeUserCommand.hidden = YES;
    }
    else
    {
        if(info.m_nCurrentSelectDevice == RCP_COMBO_DEVICE_RFID)
        {
            _olCellSymbologyPrefix.hidden = YES;
            _olCellFactory.hidden = YES;
            _olCellBarcodeUserCommand.hidden = YES;
        }
        else if(info.m_nCurrentSelectDevice == RCP_COMBO_DEVICE_NFC)
        {
            _olCellSymbologyPrefix.hidden = YES;
            _olCellFactory.hidden = YES;
            _olCellBarcodeUserCommand.hidden = YES;
        }
    }
    
}

- (NSString *)tableView:(UITableView *)tableView titleForHeaderInSection:(NSInteger)section{
    CommonReaderInfo *info = [CommonReaderInfo sharedInstance];
    NSString *strModel = info.strmodelNumber;
    switch (section) {
        case 0:
        {
            return @"Common funtions";
        }
            break;
        case 1:
        {
            if(!([strModel isEqualToString:@"ASR-010D"]
                 ||[strModel isEqualToString:@"ASR-020D"]
                 ||[strModel isEqualToString:@"ASR-022D"]
                 ||[strModel isEqualToString:@"ASR-030D"]
                 ||[strModel isEqualToString:@"ASR-031D"]
                 ||[strModel isEqualToString:@"ASR-0230DV2"]))
            {
                return @"";
            } else {
                return @"Charging control 010D,020D,022D,0230DV2,03XD";
            }
        }
            break;
        case 2:
        {
            if(!([strModel isEqualToString:@"ASR-0230D"]
                 ||[strModel isEqualToString:@"ASR-0231D"]
                 ||[strModel isEqualToString:@"ASR-0240D"]
                 ||[strModel isEqualToString:@"ASR-022D"]
                 ||[strModel isEqualToString:@"ASR-030D"]
                 ||[strModel isEqualToString:@"ASR-031D"]
                 ||[strModel isEqualToString:@"ASR-0230DV2"]))
            {
                return @"";
            } else {
                return @"Default Trigger 023XD,0240D,03XD,022D ";
            }
        }
            break;
        case 3:
        {
            if(!([strModel isEqualToString:@"ASR-0230D"]
                 ||[strModel isEqualToString:@"ASR-0231D"]
                 ||[strModel isEqualToString:@"ASR-0240D"]
                 ||[strModel isEqualToString:@"ASR-022D"]
                 ||[strModel isEqualToString:@"ASR-0230DV2"]))
            {
               return @"";
            }
            else
            {
                if(info.m_nCurrentSelectDevice == RCP_COMBO_DEVICE_RFID)
                {
                    return @"";
                }
                else if(info.m_nCurrentSelectDevice == RCP_COMBO_DEVICE_NFC)
                {
                    return @"";
                } else {
                    return @"Barcode Control  023XD,0240D,022D";
                }
            }
        }
            break;
        default:
            break;
    }
    return @"";
}
@end
